pub(crate) fn command_tree_packet<S, R>(
dispatcher: &CommandDispatcher<S, R>,
source: &S,
) -> Result<CCommands, CommandTreeProjectionError>Expand description
Builds the command graph visible to one source using vanilla packet indices.
pub(crate) fn command_tree_packet<S, R>(
dispatcher: &CommandDispatcher<S, R>,
source: &S,
) -> Result<CCommands, CommandTreeProjectionError>Builds the command graph visible to one source using vanilla packet indices.